@@ -92,12 +92,12 @@
 
 // clang-format off
 #define ROCPD_VERSION_MAJOR   1
-#define ROCPD_VERSION_MINOR   0
+#define ROCPD_VERSION_MINOR   1
 #define ROCPD_VERSION_PATCH   0
 #define ROCPD_SOVERSION       (10000 * 1)
-#define ROCPD_VERSION_STRING "1.0.0"
-#define ROCPD_GIT_DESCRIBE   "v1.0.0"
-#define ROCPD_GIT_REVISION   ""
+#define ROCPD_VERSION_STRING "1.1.0"
+#define ROCPD_GIT_DESCRIBE   ""
+#define ROCPD_GIT_REVISION   "fc0010cf6a5a972d42b276df946510f30343d493"
 
 // system info during compilation
 #define ROCPD_LIBRARY_ARCH     ""
