@@ -92,18 +92,18 @@
 
 // clang-format off
 #define ROCTX_VERSION_MAJOR   1
-#define ROCTX_VERSION_MINOR   0
+#define ROCTX_VERSION_MINOR   1
 #define ROCTX_VERSION_PATCH   0
 #define ROCTX_SOVERSION       (10000 * 1)
-#define ROCTX_VERSION_STRING "1.0.0"
-#define ROCTX_GIT_DESCRIBE   "v1.0.0"
-#define ROCTX_GIT_REVISION   ""
+#define ROCTX_VERSION_STRING "1.1.0"
+#define ROCTX_GIT_DESCRIBE   ""
+#define ROCTX_GIT_REVISION   "fc0010cf6a5a972d42b276df946510f30343d493"
 
 // system info during compilation
 #define ROCTX_LIBRARY_ARCH     ""
 #define ROCTX_SYSTEM_NAME      "Linux"
 #define ROCTX_SYSTEM_PROCESSOR "x86_64"
-#define ROCTX_SYSTEM_VERSION   "6.12.61-1-lts"
+#define ROCTX_SYSTEM_VERSION   "6.17.9-arch1-1"
 
 // compiler information
 #define ROCTX_COMPILER_ID      "GNU"
