@@ -166,18 +166,18 @@
 
 // clang-format off
 #define ROCPROFILER_SDK_VERSION_MAJOR   1
-#define ROCPROFILER_SDK_VERSION_MINOR   0
+#define ROCPROFILER_SDK_VERSION_MINOR   1
 #define ROCPROFILER_SDK_VERSION_PATCH   0
 #define ROCPROFILER_SDK_SOVERSION       1
-#define ROCPROFILER_SDK_VERSION_STRING "1.0.0"
-#define ROCPROFILER_SDK_GIT_DESCRIBE   "v1.0.0"
-#define ROCPROFILER_SDK_GIT_REVISION   ""
+#define ROCPROFILER_SDK_VERSION_STRING "1.1.0"
+#define ROCPROFILER_SDK_GIT_DESCRIBE   ""
+#define ROCPROFILER_SDK_GIT_REVISION   "fc0010cf6a5a972d42b276df946510f30343d493"
 
 // system info during compilation
 #define ROCPROFILER_SDK_LIBRARY_ARCH     ""
 #define ROCPROFILER_SDK_SYSTEM_NAME      "Linux"
 #define ROCPROFILER_SDK_SYSTEM_PROCESSOR "x86_64"
-#define ROCPROFILER_SDK_SYSTEM_VERSION   "6.12.61-1-lts"
+#define ROCPROFILER_SDK_SYSTEM_VERSION   "6.17.9-arch1-1"
 
 // compiler information
 #define ROCPROFILER_SDK_COMPILER_ID      "GNU"
@@ -190,18 +190,18 @@
 
 // clang-format off
 #define ROCPROFILER_VERSION_MAJOR   1
-#define ROCPROFILER_VERSION_MINOR   0
+#define ROCPROFILER_VERSION_MINOR   1
 #define ROCPROFILER_VERSION_PATCH   0
 #define ROCPROFILER_SOVERSION       1
-#define ROCPROFILER_VERSION_STRING "1.0.0"
-#define ROCPROFILER_GIT_DESCRIBE   "v1.0.0"
-#define ROCPROFILER_GIT_REVISION   ""
+#define ROCPROFILER_VERSION_STRING "1.1.0"
+#define ROCPROFILER_GIT_DESCRIBE   ""
+#define ROCPROFILER_GIT_REVISION   "fc0010cf6a5a972d42b276df946510f30343d493"
 
 // system info during compilation
 #define ROCPROFILER_LIBRARY_ARCH     ""
 #define ROCPROFILER_SYSTEM_NAME      "Linux"
 #define ROCPROFILER_SYSTEM_PROCESSOR "x86_64"
-#define ROCPROFILER_SYSTEM_VERSION   "6.12.61-1-lts"
+#define ROCPROFILER_SYSTEM_VERSION   "6.17.9-arch1-1"
 
 // compiler information
 #define ROCPROFILER_COMPILER_ID      "GNU"
