@@ -27,9 +27,9 @@ LD_LIBRARY_PATH=${BASEDIR}/lib:${LD_LIBRARY_PATH}
 CMAKE_PREFIX_PATH=${BASEDIR}:${CMAKE_PREFIX_PATH}
 
 if [ -z "" ]; then
-    PYTHONPATH=$(rocprofiler_sdk_roctx_get_python3_path):${PYTHONPATH}
+    PYTHONPATH=$(rocprofiler_sdk_roctx_get_python3_path):${BASEDIR}/lib/python3/site-packages:${PYTHONPATH}
 else
-    PYTHONPATH=${BASEDIR}/:${PYTHONPATH}
+    PYTHONPATH=${BASEDIR}/:${BASEDIR}/lib/python3/site-packages:${PYTHONPATH}
 fi
 
 unset rocprofiler_sdk_roctx_get_python3_path
